Struct ZwpLinuxExplicitSynchronizationV1
pub struct ZwpLinuxExplicitSynchronizationV1 { /* private fields */ }wayland and Linux only.Expand description
protocol for providing explicit synchronization
This global is a factory interface, allowing clients to request explicit synchronization for buffers on a per-surface basis.
See zwp_linux_surface_synchronization_v1 for more information.
This interface is derived from Chromium’s zcr_linux_explicit_synchronization_v1.
Note: this protocol is superseded by linux-drm-syncobj.
Warning! The protocol described in this file is experimental and backward incompatible changes may be made. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes are done by bumping the version number in the protocol and interface names and resetting the interface version. Once the protocol is to be declared stable, the ‘z’ prefix and the version number in the protocol and interface names are removed and the interface version number is reset.
This interface has no events.
Implementations
impl ZwpLinuxExplicitSynchronizationV1
impl ZwpLinuxExplicitSynchronizationV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy explicit synchronization factory object
Destroy this explicit synchronization factory object. Other objects, including zwp_linux_surface_synchronization_v1 objects created by this factory, shall not be affected by this request.
pub fn get_synchronization<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpLinuxSurfaceSynchronizationV1
pub fn get_synchronization<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> ZwpLinuxSurfaceSynchronizationV1
extend surface interface for explicit synchronization
Instantiate an interface extension for the given wl_surface to provide explicit synchronization.
If the given wl_surface already has an explicit synchronization object associated, the synchronization_exists protocol error is raised.
Graphics APIs, like EGL or Vulkan, that manage the buffer queue and commits of a wl_surface themselves, are likely to be using this extension internally. If a client is using such an API for a wl_surface, it should not directly use this extension on that surface, to avoid raising a synchronization_exists protocol error.